@@ -185,6 +185,10 @@ int getRxNobs(rx_solve *rx) {
 int getRxNobs2(rx_solve *rx) {
   return rx->nobs2;
 }
+
+int getRxNpars(rx_solve *rx) {
+  return rx->npars;
+}
 ////////////////////////////////////////////////////////////////////////
 // Get solve vector for ith solve
 ////////////////////////////////////////////////////////////////////////
